[![Codacy Badge](https://api.codacy.com/project/badge/Grade/3f9ac104a1444a57a1a5287e95830a84)](https://www.codacy.com/app/andriopau/pymdsetup?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=bioexcel/pymdsetup&amp;utm_campaign=Badge_Grade)
[![Documentation Status](https://readthedocs.org/projects/pymdsetup/badge/?version=latest)](http://pymdsetup.readthedocs.io/en/latest/?badge=latest)

# biobb_common

### Introduction
Biobb_common is the base package required to use the biobb
packages.
Biobb (Bio building blocks) packages are Python building blocks that
create new layer of compatibility and interoperability over popular
bioinformatics tools.
The latest documentation of this package can be found in our readthedocs site:
[latest API documentation](http://biobb_common.readthedocs.io/en/latest/).

### Version 0.0.1
This version is the first Alpha.

### Copyright & Licensing
This software has been developed in the MMB group (http://mmb.pcb.ub.es) at the
BSC (http://www.bsc.es/) & IRB (https://www.irbbarcelona.org/) for the European BioExcel (http://bioexcel.eu/), funded by the European Commission
(EU H2020 [675728](http://cordis.europa.eu/projects/675728)).

* (c) 2015-2017 [Barcelona Supercomputing Center](https://www.bsc.es/)
* (c) 2015-2017 [Institute for Research in Biomedicine](https://www.irbbarcelona.org/)

Licensed under the
[Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0), see the file
[LICENSE](LICENSE) for details.

<!--
The file [NOTICE](NOTICE) contains any additional attributions and
details about embedded third-party libraries and source code.
-->

![](docs/source/_static/bioexcel_logo.png "Bioexcel")
